@@ -10,7 +10,7 @@ from matplotlib.font_manager import FontProperties
 
 FONT_PATH = resource_filename("multidirectional_graph", "fonts")
 TITLE_FONT_PATH = os.path.join(FONT_PATH, "Oswald", "Oswald-Regular.ttf")
-BASE_FONT_PATH = os.path.join(FONT_PATH, "SourceSerif", "SourceSerifPro-Light.ttf")
+BASE_FONT_PATH = os.path.join(FONT_PATH, "SourceSerif", "SourceSerifPro-Regular.ttf")
 
 
 class MultidirectionalGraph:
@@ -25,7 +25,9 @@ class MultidirectionalGraph:
         aspect_ratio: float = 2.5,
         black_color: str = "#202020",
         odd_group_color: str = "#e3e0d2",
+        odd_group_light_color: str = "#fbfbfa",
         even_group_color: str = "#efeee6",
+        even_group_light_color: str = "#f9f8f6",
         bad_color: str = "#f5e8e3",
         bad_range: Tuple[int] = (1, 4),
         bad_string: str = "Precisa de\ndesenvolvimento",
@@ -52,9 +54,12 @@ class MultidirectionalGraph:
         background_alpha: float = 1,
         title_font_path: str = TITLE_FONT_PATH,
         base_font_path: str = BASE_FONT_PATH,
-        plot_base_options = dict(zorder=2),
-        scatter_base_options = dict(color="white", marker='o', zorder=3),
-        legend_displacement = (0.5, -0.06),
+        plot_base_options: dict = dict(zorder=2),
+        scatter_base_options: dict = dict(color="white", marker='o', zorder=3),
+        legend_displacement: Tuple[float] = (0.5, -0.08),
+        category_fontsize: int = 9,
+        main_plot_color: str = "#202020",
+        group_title_fontsize: str = 9,
     ):
         """
         A class to create a multidirectional graph based on input data.
@@ -82,8 +87,12 @@ class MultidirectionalGraph:
             The color of the lines in the graph, by default "#202020".
         odd_group_color : str, optional
             The background color of odd-numbered groups in the graph, by default "#efeee6".
+        odd_group_light_color: str
+            The background light color of odd-numbered groups in the graph.
         even_group_color : str, optional
             The background color of even-numbered groups in the graph, by default "#e3e0d2".
+        even_group_light_color: str
+            The background light color of even-numbered groups in the graph.
         bad_color : str, optional
             The color used to indicate values that need development, by default "#e51951".
         bad_range : Tuple[int], optional
@@ -130,6 +139,18 @@ class MultidirectionalGraph:
             The path of title font
         base_font_path: str
             The path of base font
+        scatter_base_options: dict
+            Options to be passed to scatter main plot
+        plot_base_options: dict
+            Options to be passed to main plot
+        legend_displacement: Tuple[float]
+            A tuple with displacements of legend
+        category_fontsize: int
+            Fontsize of categories on y-axis
+        main_plot_color: str
+            Color of main plot
+        group_title_fontsize: int
+            The fontsize of group titles
         """
         self.revert_data = revert_data
         self.data = self._set_data(data)
@@ -145,7 +166,9 @@ class MultidirectionalGraph:
         self.max_y = self.n_categories - 0.5
         self.black_color = black_color
         self.odd_group_color = odd_group_color
+        self.odd_group_light_color = odd_group_light_color
         self.even_group_color = even_group_color
+        self.even_group_light_color = even_group_light_color
         self.bad_color = bad_color
         self.bad_range = bad_range
         self.bad_string = bad_string
@@ -169,6 +192,17 @@ class MultidirectionalGraph:
         self.background_alpha = background_alpha
         self.title_font_path = title_font_path
         self.base_font_path = base_font_path
+        self.group_title_fontsize = group_title_fontsize
+
+        self.scatter_base_options = scatter_base_options
+        self.plot_base_options = plot_base_options
+        self.legend_displacement = legend_displacement
+        self.bad_font_color = bad_font_color
+        self.neutral_font_color = neutral_font_color
+        self.good_font_color = good_font_color
+        self.category_fontsize = category_fontsize
+        self.main_plot_color = main_plot_color
+
         self.title_font = FontProperties(fname=self.title_font_path)
         self.base_font = FontProperties(fname=self.base_font_path)
         self.rectangle_left = self.min_x - self.category_width - self.group_width
@@ -181,12 +215,8 @@ class MultidirectionalGraph:
         self.additional_values = []
         self.additional_values_labels = []
         self.additional_values_options = []
-        self.scatter_base_options = scatter_base_options
-        self.plot_base_options = plot_base_options
-        self.legend_displacement = legend_displacement
-        self.bad_font_color = bad_font_color
-        self.neutral_font_color = neutral_font_color
-        self.good_font_color = good_font_color
+
+        self.group_colors
 
     def set_param(self, field, value):
         if not hasattr(self, field):
@@ -215,15 +245,18 @@ class MultidirectionalGraph:
         self.ax = plt.subplot(111, aspect=self.aspect_ratio)
         self._configure_axis(self.ax)
 
-        self.ax.plot(self.values, self.categories, color=self.black_color, label=self.label, linewidth=self.linewidth, **self.plot_base_options)
-        self.ax.scatter(self.values, self.categories, edgecolor=self.black_color, linewidth=self.linewidth, **self.scatter_base_options)
+        mean = np.mean(self.values)
+        label = self.label + "\n( {:.2f} )".format(mean)
+
+        self.ax.plot(self.values, self.categories, color=self.main_plot_color, label=label, linewidth=self.linewidth, **self.plot_base_options)
+        self.ax.scatter(self.values, self.categories, edgecolor=self.main_plot_color, linewidth=self.linewidth, **self.scatter_base_options)
 
         self._plot_additional_values(self.ax)
 
         self._set_limits(self.ax)
         self._set_y_ticks_colors(self.ax)
 
-        self.ax.legend(
+        legend = self.ax.legend(
             loc='lower center',
             bbox_to_anchor=self.legend_displacement,
             ncol=2,
@@ -231,6 +264,10 @@ class MultidirectionalGraph:
             borderaxespad=-0.1,
             prop=self.base_font,
         )
+
+        for leg in legend.get_texts():
+            leg.set_ha("center")
+
         self.fig.tight_layout()
 
         return self.fig
@@ -238,7 +275,8 @@ class MultidirectionalGraph:
     def _plot_additional_values(self, ax):
         for i, value_list in enumerate(self.additional_values):
             opt = self.additional_values_options[i]
-            label = self.additional_values_labels[i]
+            mean = np.mean(value_list)
+            label = self.additional_values_labels[i] + "\n( {:.2f} )".format(mean)
             ax.plot(value_list, self.categories, label=label, **opt)
             ax.scatter(value_list, self.categories, edgecolor=opt["color"], linewidth=opt["linewidth"], **self.scatter_base_options)
 
@@ -277,7 +315,8 @@ class MultidirectionalGraph:
             y_value = self.values[i]
 
             colors = {k[0]: self.background_bins[k]["color"]  for k in self.background_bins}
-            label.set_font_properties(self.base_font)                
+            label.set_font_properties(self.base_font)
+            label.set_fontsize(self.category_fontsize)
 
             if 1 <= y_value < 4.5:
                 label.set_color(self.bad_font_color )
@@ -305,6 +344,10 @@ class MultidirectionalGraph:
             group: self.even_group_color if i % 2 == 0 else self.odd_group_color
             for i, group in enumerate(self.data)
         }
+        self.group_light_colors = {
+            group: self.even_group_light_color if i % 2 == 0 else self.odd_group_light_color
+            for i, group in enumerate(self.data)
+        }
 
     def _set_background_bins(self):
         self.background_bins = {
@@ -330,7 +373,7 @@ class MultidirectionalGraph:
         return {d: len(self.data[d]) for d in self.data}
 
     def _set_title(self):
-        self.title = f"AVALIAÇÃO MULTIDIRECIONAL DE\n{self.tipo_avaliacao}".upper()
+        self.title = f"{self.tipo_avaliacao}".upper()
 
     def _add_title(self, ax):
         self._set_title()
@@ -422,7 +465,6 @@ class MultidirectionalGraph:
                     [self.max_y,self.max_y+self.subheader_height],
                     clip_on=False,
                     color=self.black_color,
-                    # alpha=0.5,
                     linewidth=0.5,
                 )
             )
@@ -447,7 +489,7 @@ class MultidirectionalGraph:
                     ),
                     self.category_width,
                     size,
-                    facecolor=self.group_colors[group],
+                    facecolor=self.group_light_colors[group],
                     clip_on=False,
                     linewidth=0,
                     alpha=0.2,
@@ -473,7 +515,7 @@ class MultidirectionalGraph:
                 ha="center",
                 va="center",
                 fontproperties=self.title_font,
-                fontsize=int(0.85*self.title_fontsize),
+                fontsize=self.group_title_fontsize,
             )
 
 
